Module: Barbeque::Executor

Defined in:
lib/barbeque/executor.rb,
lib/barbeque/executor/hako.rb,
lib/barbeque/executor/docker.rb

Overview

Executor is responsible for starting executions and getting status of executions. Each executor must implement these methods.

  • #initialize(options)
    • Create a executor with executor_options specified in config/barbeque.yml.
  • #start_execution(job_execution, envs)
    • Start execution with environment variables. An executor must update the execution status from pending.
  • #poll_execution(job_execution)
    • Get the execution status and update the job_execution columns.
  • #start_retry(job_retry, envs)
    • Start retry with environment variables. An executor must update the retry status from pending and the corresponding execution status.
  • #poll_retry(job_retry)
    • Get the execution status and update the job_retry and job_execution columns.

Defined Under Namespace

Classes: Docker, Hako

Class Method Summary collapse

Class Method Details

.create ⇒ Object



24
25
26
27
# File 'lib/barbeque/executor.rb', line 24

def self.create
  klass = const_get(Barbeque.config.executor, false)
  klass.new(Barbeque.config.executor_options)
end